---
title: "Social Construction and Madness"
date: 2022-07-23T17:28:42+01:00
tags: ["objects", "constructs", "meaning", "teleology", "nature"]
topics: ["ontology", "metaphysics", "sociology"]
image: img/madman-wide.jpg
description: Initial Musings on Social Objects
draft: false
---

> "*Today is a great triumph. There **is** a king of Spain. He has been found at last. That king is **me**.*" ~ Nikolai Gogol

What makes a "social object" "really real"? What is a "social object", and what would it mean for *anything* to be "really real", as opposed to just plain real? The common-sense (ala naive) understanding, is to suggest that things like chairs and tennis balls and bullets are "really real", while things like "money" and "borders" and "kings" are only just "socially" real (if real at all). However, depending on the scope of the analysis, it is not so easy to draw the line implicit in the previous examples.

What is the difference between a "social" object, and "real object"?

First, what is a real object? In modern realist ontologies, objects are something like discrete packets of material with an identifiable, stable form, and an inviolable boundary. So, everything from sub-atomic particles, to planets, to a pair of blue jeans, a coffee mug, a mosquito, a man, and a copy of Philosophy Now magazine, all count as objects, because they all are all composed of certain kinds of material, that material takes a form that can be expressed in mathematical or logical or descriptive terms, and no two of them could occupy the same space at the same time.

But this is only half the story of "real" objects. Why do we call a planet a planet? Why do we call a magazine a magazine? Ontology focuses so tightly on the *thatness* of things, that it tends to ignore the *whatness* of them. But it is the *whatness* that makes it possible for us to distinguish one thing from another not just in a quantitative sense (ala Quine), but in a *qualitative* sense. It's not *just* an object, but *a planet* that I am looking at, through my telescope. It is not just an object from which I am reading a passage to you, but a *magazine*. Things aren't *just* things, in some indiscriminate, undifferentiated abstract way. They are *instances of kinds*. A magazine is not the *kind* of thing that a planet is. A chair is not the *kind* of thing a king is.

Where I am going with this, is to suggest that *everything*, to a certain extent, and in certain ways, is a social object. Namely, social agreement is required to establish the *nature* of almost every object. Whether we're talking about the characteristics of sub-atomic particles, or the structural constitution of a government, it is social negotiations of various kinds that are necessary to establish agreement on what is and is not "real" about those things. For scientists, it is the scientific method applied in experimentation and collaboration, that function as the form of negotiation. For politicians and citizens, it is public debate, policymaking, voting, and armed conflict that function as the form of negotiation. For the everyday person, it is experiential corroboration that functions as the form of negotiation ("do you see what I see?"). It is this last form that tends to be taken for "common sense" ontology. Social construction, therefore, is at the heart of all ontology, whether we realize it or not. But there is a right way and a wrong way to do social construction.

The everyday experience of reality is not just as collection of things, but also as a *forum for acting*. Things have their meanings (are given their reality) in relation to the *role they play* in the *ends of human action*. (Peterson, Maps of Meaning, Chapter 1). A chair is an object of a certain kind. It has a specific shape, a specific material composition, a specific creative history, and especially, *a specific use*. While it is true that there would be no chairs if there were no humans, this is a trivial fact. The more interesting observation, is that there would be no chairs, if men did not want them.

But, would that also mean there would be no trees, if men did not want them? Setting aside the impulse to clear-cutting, the point here, is that there are some things that seem to have their meanings - their *whatness* - independent of human intention. It is that independence that seems to be at the center of the "really real" complaint. But implicit in that complaint, is the presupposition that the human experience of a thing somehow cannot count toward its reality. That chairs are only "real" in some vague metaphorical sense, as compared to trees, because chairs depend a great deal more on their relation to human experience, for their existence (as expressed in their meaning). In short, the degree to which a thing's nature is dependent upon social agreement, is the degree to which its reality will be disputed. And the degree to which its reality is disputed, is the degree to which the object's meaning is intertwined with human experience. But the problem isn't whether the things we call trees would disappear if we didn't want them. The problem is, whether those things would have a *different nature* if we had a different relation to them. Let's look at a different example, that will make this point more clear.

There is little *use* we can make of planets (at least, for right now). But there is a consistent experience of them, up in the heavens, exhibiting certain properties, and behaving in certain ways. However, there is dispute over them. Astronomers have been arguing for decades over whether Pluto actually *is* a planet or not. Before that, they were arguing over whether there *was* a Pluto (whether planet, or not). This is an interesting example to explore, on the question of the reality of social objects, because it nicely defines an important categorical boundary.

The question of whether or not there *is* a Pluto, is a question of its *thatness*. In other words, *that* it exists. The question of whether or not Pluto *is a planet*, is a question of its *whatness*. In otherwords, *what* exists. The former is almost entirely a purely empirical question. When we look up at the night sky, in the right place, at the right time, do we we see something? And can we distinguish it numerically from other somethings that we've already seen? There is a minimal amount of social negotiation involved in this, but only to the extent of corroboration. You would be asking your colleague, do you have the same visual experience that I have? Assuming you both have reasonably good equipment, are competent with telescopes, and are visually healthy, you'll come to the same answer. The latter question, however, is a question of identifying *the nature* of the thing seen. Do you see *what* I see? Do you see a *planet*? Your colleague might say, no, he sees an asteroid. And the answer you got would depend mainly on the outcome of social negotiations that took place around the time that you asked. In 1966, he would have answered, yes, he sees a planet.

The shift in identification and definition of the 9th celestial body in the solar system has as much to do with the politics of NASA's purpose, as it does with the property specifications of celestial bodies. In otherwords, the *nature* of Pluto is partially dependent on the *purposes* man intends for Pluto -- the role it plays in our ends. The same is true for money, borders, social institutions, and -- to raise a popular contemporary debate -- gender identities.

The arguments presently swirling around in popular culture over who is and who is not "a woman", are roughly analogous to the arguments over whether Pluto is or is not a planet. To a certain extent, the traditionalists are correct. There is a material reality to be contended with. Just as the celestial body is "really real", the human body is "really real". But the question is, what is *the nature* of the human body? There are, of course, property specifications for kinds of human bodies. While it is true that those property specifications do distinquish between two different *kinds* of human bodies, the question before society now seems to be, what *role* do those bodies play in the end of human action?

Admittedly, this is a slightly more complicated problem than the question of Pluto. This is because Pluto is purely an *object*, on which humans often focus their attentions, and *intentions*. However, when we look inward, at our own societies and ourselves, what we find are *both* objects and subjects, simultaneously. I *am*. But *what* I am is dependent as much on my physical characteristics, as what role I play both for myself, and for the society within which I act. That role is the end result of a complex and continuous negotiation with myself, and with the people around me, and is going to be heavily characterized by the theological and philosophical narratives that give the society its ultimate shape.

In the past, the end of human action was *the good*, both in a relative and an absolute sense, as revealed to us through philosophy and scripture. Male and female -- man and woman -- were complementary identities that cooperatively served the pursuit of *the good*, by way of the establishment of families, and the distribution of social responsibilities like protection, provision, nurturing, and tutoring, across those complementary identities as was prescribed by social institutions. Genders, and their tightly associated roles, served to orient the society toward *the good* implied in its theological and philosophical narratives describing its common ends. But the theological and philosophical narratives of *this* society have all been either relegated to obscurity or outright abandoned over the last 300 years, and *the good* that served as the guiding star for it is no longer visible to it. As such, one by one, all of this society's "social objects" that were once very real, are gradually falling out of existence.

The gender debate is just one more of these existential collapses, and it is happening with such aggressive force, that some are even struggling to recognize the underlying material reality below it. Imagine a fight over Pluto so vociferous, that astronomers were actually questioning themselves when they looked into their telescopes, as to whether they were really seeing anything at all. On the other end of the spectrum today, we see examples of Gogol's infamous madman everywhere we look. Everyone is now his own King of Spain. Only, we are not limited to merely being one more King of Spain. Some of us are dragons and dogs, some ornate buildings and transdimensional aliens, and some are at one moment men, and another moment women. In short, having disconnected ourselves from the *the good* as a common object, it is now the case that both *everything* and *nothing* is "really real". Which is to say, nothing can be said about what is real.

Social objects are "really real", but only insofar as they are the result of a *meaningful* construction process, and *meaningful* construction is only possible when man is capable of discovering and orienting himself toward *the good*. Thus oriented, his intentions and actions will impose a role on objects that bring them into existence as a part of the common end of *the good*, and will give them a natural place in the hiearchy of being, oriented toward that good. Without that common end, all ends are disparate and irreconcilable, because every individual not only *has* his own ends, but *is* his own end. This, in turn, makes impossible the social negotiation necessary for the construction of social objects. The end result is what we see in the popular culture today: wars of will and caprice. Social hierarchies formed haphazardly around a debased notion of power (some of us would call that evil), rather than a collective aspiration toward the common end of *the good* (some of us would call that God).