---
title: "The Platonism of the Categorical Imperative"
date: 2018-03-16T22:44:22Z
tags: ["plato","kant","categorical imperative","forms","eidos","transcendence"]
topics: ["philosophy"]
image: img/shapes.jpg
draft: false
---

Moral maxims are rules governing actions, or commands to act in certain ways considered morally correct. Some of the most well known maxims are those that come to us by way of religious tradition. “Thou Shalt Not Kill” and “Thou Shalt Not Bear False Witness” are paradigm examples. Kant insists that his Categorical Imperative is the best means by which to test the maxims, for whether they correctly guide us to right action and away from wrong action. In this essay, I will argue that while the Categorical Imperative might seem plausible as a test of moral maxims because of it’s rigid logical form, it actually fails the plausibility test for one of the same reasons Parmenides rejected Socrates’ conception of the Forms.

In brief, the Categorical Imperative test is a thought experiment in which one attempts to universalize the maxim in question in order to discover a logical impossibility, or at least, an absurdity embedded in the consequences. Here’s how he states it:

> “Act only according to that maxim whereby you can at the same time will that it should become a universal law.”

But there is a second, very closely related formulation, that looks like this:

> “Act as if the maxims of your action were to become through your will a universal law of nature.”

The difference between these two might seem insignificant on the surface, but they represent a fundamental Platonic tension in Kant’s metaphysics of morals, which I’ll explain more fully, after outlining the distinction between these two a bit better. In the first conception, Kant is describing a feature of his *moral law*. In the second, he is making explicit reference to the *natural law*, in the Newtonian sense. He wants to link them because of their fundamental universality, but this linkage is only an analogy; the two universalities are fundamentally different in kind. In the case of *natural law*, scientists subsequent to Newton were attempting to *infer* the presence of a structure of rational intelligibility from the regularities and consistencies they observed, and in some cases could predict, in the behavior of objects in the mechanical universe given to us by Newton.

Kant rightly recognized the lack of ultimate *necessity* in these laws, and goes on about it at length in the Groundwork. He does this, because he needs his *moral law* to be something that is ultimately good, and that *could not have been otherwise*. In order to arrive at this, Kant has to borrow the notion of a telos for man from Aristotle. As with Aristotle, Kant chooses *reason* as the basis for that telos. But unlike Aristotle, Kant insists that the reason he has in mind is not the reason Aristotle wants us to accept. Aristotle’s reason would have us pursuing material ends that satisfy the conditions of living. For Kant, this is unacceptable. He makes a distinction between the rational mind of contingency, and the faculty of pure reason capable of discerning the absolutes of *moral law*, in the same way that Socrates would have us contemplating the Forms, in *Republic* or *Phaedrus*. The former is the basis for what Kant regards as “hypothetical imperatives”. These sorts of imperatives, he argues, can be of only relative or instrumental value, because they arise out of the contingency of circumstances and the temporal calculations of cost and benefit. For Kant, such imperatives could not constitute *moral* imperatives because they lack the constancy and objectivity of a mathematical equation or a geometric expression; in other words, the kind of truth that is true everywhere, at all times, and applicable to all rational beings – a_universal_ truth, of the kind envisioned in Plato’s description of the Form of The Good.

Intuitively, the ascendence into Platonic idealism may seem like a good idea. After all, why would we call a rule that only applied circumstantially a “moral rule”? Wouldn’t that simply be a convention, or a preference? Indeed, for Kant, the universal law of the Categorical Imperative is not derived from natural law, in the way that Newton’s laws of thermodynamics, for instance, are derived by inferring them from the behavior of matter. Rather, the Categorical Imperative is derived from the *moral law* which is accessible only by means of the faculty of “pure reason”, as an entirely contemplative exercise. Kant goes so far with this concept as to suggest that there may be no acceptable method for justifying the Categorical Imperative itself by any exemplary application of the self-same principle:

> “…how could laws of the determination of the will be regarded as laws of the determination of the will of rational beings generally… if they were merely empirical and did not take their origin wholly **a priori** from pure but practical reason? Nor could anything be more fatal to morality than that we should wish to derive it from examples. For every example of it that is set before me must be first itself tested by principles of morality, whether it is worthy to serve as an **original** example… but by no means can it authoritatively furnish the conception of morality… imitation finds no place at all in morality, and examples serve only for encouragement… they can never authorize us to set aside the true original which lies only in reason…”

Kant is invoking the ghost of Socrates here by complaining that examples are not enough, and that what he seeks is a universal definition for right action that can be contemplated in the realm of the intelligible, like the Form of the Good or the Form of Beauty. But Kant is also invoking the ghost of Parmenides here, by reminding us that the *ideal* good will, and the *actual* good will, do not seem to have any relation or connection to each other. As put by G. M. A. Grube:

> If the [Forms] are not of our world, they are totally separate and there can be no connexion between the two. The [Forms] cannot then be objects of knowledge… If anyone has knowledge of them, a god has, but this knowledge of the Forms is beyond us human beings. We cannot know the god and the god cannot know us.

Kant even attempts to remedy this in his own metaphysics by positing a nearly identical Nuemenal Realm for his *moral law* as Socrates posits for Parmenides for his Forms (from Parmenides):

> Could not, Parmenides, each of these Forms be a noema which cannot properly exist elsewhere than in souls? For then each of them would be one and what you said just now would not apply to it…

This could be the reason why Kant gives us these two different formulations of the Categorical Imperative — a difference that should appear much more stark now than at the beginning of this essay. Kant is trying to provide towers on either side of the chasm he’s attempting to bridge, with his “good will”. What’s more, Plato’s Forms are attempting to conceptualize an ideal for static objects of subjective experience, such as beauty or justice, or the shape of a triangle. But Kant is demanding the same standard of perfection for human action, as it manifests itself in the material world. There can be no perfect form of right action, because all of human action is bounded by contingency in the facts of reality. The Categorical Imperative is, therefore, a profoundly confused misapplication of Platonic Idealism.

It is telling, then, that Kant struggles so mightily in attempting to demonstrate the utility of the Categorical Imperative in the various examples he offers (and that earlier he complained could provide no true representation of it, much like Socrates would have complained of the Form of man). The case of the false promise, for example, does not expose a logical contradiction any more than Hume’s teapot refusing to boil does. Instead, all Kant is able to show, is how a world of nothing but false promises would seem a whimsically ridiculous place to us. The recognition of the absurdity in consequence is not the same thing as contemplating the injustice of the violation of a universal moral law. Even worse, the recognition of that absurdity exposes the fact that we’re implicitly dealing with a *hypothetical* imperative here: If you want to be able to rely on promises, then you need to honor them and expect others will do the same. Imagining this as some species of a Categorical Imperative residing in an intelligible realm of *moral law* renders you no less vulnerable to the unscrupulous man. But, more to the point, it leaves you with no clear reason to condemn him as having *acted immorally*. At best, you could complain about the inconvenience or the harm, at which point, you’d be applying a consequentialist standard, and our unscrupulous man could simply retort that its up to you to indemnify yourself against such a contingency in the real world.

For anyone who already prizes the beauty or the utility of the universal applicability of mathematics, or who is already wedded to the universal divinity of the human soul, Kant’s Categorical imperative is going to be powerfully seductive, as a moral system. If we all lived in a rational paradise in fact, then maybe we’d all be like that and Kant would just be another in a long pantheon of Philosopher Kings, ruling us rationally from the pulpit of the Form of Right Action, or the Form of The Good. For the rest of us in the real world, however, where life is lived in pursuit of contingent and temporal goals, the Categorical Imperative is at best a useful heuristic, and at worst, an oppressive ideal that renders us all moral failures at the outset.
